---
name: Bug report
about: Information to fill in for reporting bugs
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A short description of what the bug is.

**To Reproduce**
Steps to reproduce the behaviour

**Expected behavior**
What you expected to see

**Environment **
 - OS:
 - `delfies` version: 
- How `delfies` was installed:
